@@ -1,7 +1,7 @@
 package Bencher::Scenario::DateTimeFormatAlami::Startup;
 
-our $DATE = '2016-04-07'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2016-06-29'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -11,9 +11,9 @@ our $scenario = {
     summary => 'Benchmark startup of DateTime::Format::Alami against some other modules',
     module_startup => 1,
     participants => [
-        {module=>'DateTime::Format::Alami'},
         {module=>'DateTime::Format::Alami::EN'},
         {module=>'DateTime::Format::Alami::ID'},
+        {module=>'DateTime::Format::Flexible'},
         {module=>'DateTime::Format::Natural'},
         {module=>'DateTime'},
     ],
@@ -34,7 +34,7 @@ Bencher::Scenario::DateTimeFormatAlami::Startup - Benchmark startup of DateTime:
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::DateTimeFormatAlami::Startup (from Perl distribution Bencher-Scenarios-DateTimeFormatAlami), released on 2016-04-07.
+This document describes version 0.003 of Bencher::Scenario::DateTimeFormatAlami::Startup (from Perl distribution Bencher-Scenarios-DateTimeFormatAlami), released on 2016-06-29.
 
 =head1 SYNOPSIS
 
@@ -48,26 +48,20 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<DateTime::Format::Alami> 0.06
+L<DateTime::Format::Alami::EN> 0.11
 
-L<DateTime::Format::Alami::EN> 0.06
+L<DateTime::Format::Alami::ID> 0.11
 
-L<DateTime::Format::Alami::ID> 0.06
+L<DateTime::Format::Flexible> 0.26
 
 L<DateTime::Format::Natural> 1.03
 
-L<DateTime> 1.26
+L<DateTime> 1.27
 
 =head1 BENCHMARK PARTICIPANTS
 
 =over
 
-=item * DateTime::Format::Alami (perl_code)
-
-L<DateTime::Format::Alami>
-
-
-
 =item * DateTime::Format::Alami::EN (perl_code)
 
 L<DateTime::Format::Alami::EN>
@@ -80,6 +74,12 @@ L<DateTime::Format::Alami::ID>
 
 
 
+=item * DateTime::Format::Flexible (perl_code)
+
+L<DateTime::Format::Flexible>
+
+
+
 =item * DateTime::Format::Natural (perl_code)
 
 L<DateTime::Format::Natural>
@@ -96,20 +96,21 @@ L<DateTime>
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.1 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
+Run on: perl: I<< v5.22.1 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with default options (C<< bencher -m DateTimeFormatAlami::Startup >>):
 
- +-----------------------------+-----------+------------------------+------------+---------+---------+
- | participant                 | time (ms) | mod_overhead_time (ms) | vs_slowest | errors  | samples |
- +-----------------------------+-----------+------------------------+------------+---------+---------+
- | DateTime::Format::Natural   | 70.5      | 65.3                   | 1          | 6e-05   | 20      |
- | DateTime                    | 49.7      | 44.5                   | 1.42       | 3.3e-05 | 20      |
- | DateTime::Format::Alami::EN | 16        | 10.8                   | 4.4        | 2.1e-05 | 23      |
- | DateTime::Format::Alami::ID | 16        | 10.8                   | 4.5        | 1.9e-05 | 20      |
- | DateTime::Format::Alami     | 14.3      | 9.1                    | 4.93       | 1e-05   | 20      |
- | perl -e1 (baseline)         | 5.2       | 0                      | 13         | 6.7e-06 | 20      |
- +-----------------------------+-----------+------------------------+------------+---------+---------+
+ #table1#
+ +-----------------------------+-----------+------------------------+------------+-----------+---------+
+ | participant                 | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors   | samples |
+ +-----------------------------+-----------+------------------------+------------+-----------+---------+
+ | DateTime::Format::Flexible  |       120 |                    115 |        1   |   0.00063 |      21 |
+ | DateTime::Format::Natural   |        82 |                     77 |        1.4 |   0.00035 |      21 |
+ | DateTime                    |        60 |                     55 |        2   |   0.00069 |      20 |
+ | DateTime::Format::Alami::ID |        24 |                     19 |        4.9 |   0.00013 |      20 |
+ | DateTime::Format::Alami::EN |        23 |                     18 |        5   | 4.1e-05   |      20 |
+ | perl -e1 (baseline)         |         5 |                      0 |       20   | 6.1e-05   |      20 |
+ +-----------------------------+-----------+------------------------+------------+-----------+---------+
 
 =head1 DESCRIPTION
 
